From: Johannes Schindelin Date: Mon, 02 Sep 2019 14:47:14 GMT Subject: Re: [PATCH v4 1/4] t6006: simplify and optimize empty message test Message-ID: In-Reply-To: <20190830055707.7785-2-newren@gmail.com> Hi Elijah, On Thu, 29 Aug 2019, Elijah Newren wrote: > Despite only being one piece of the 71st test and there being 73 tests > overall, this small change to just this one test speeds up the overall > execution time of t6006 (as measured by the best of 3 runs of `time > ./t6006-rev-list-format.sh`) by about 11% on Linux and by 13% on > Mac. A similar effect can be observed on my Windows laptop: from 25s to 21s, i.e. ~15%. Thanks, Dscho